@@ -20,16 +20,34 @@ set -e
 IMAPUSER_TABLE=/usr/share/doc/benno-imap/imapuser.sql
 DATABASE_DIR=/var/lib/benno-web
 DATABASE_FILE="$DATABASE_DIR/bennoweb.sqlite"
+CONF_DIR=/etc/benno-imap
+PUBKEY=/etc/benno-imap/benno-imap.pub
+SECKEY=/etc/benno-imap/benno-imap.sec
 
 
 case "$1" in
     configure)
         set +e
-        sqlite3 "$DATABASE_FILE" < "$IMAPUSER_TABLE" 2>/dev/null
-        chgrp benno "$DATABASE_DIR"
-        chgrp benno "$DATABASE_FILE"
-        chmod 0770 "$DATABASE_DIR"
-        chmod 0660 "$DATABASE_FILE"
+        if [ -f "$DATABASE_FILE" ];then
+            sqlite3 "$DATABASE_FILE" < "$IMAPUSER_TABLE" 2>/dev/null
+            chgrp benno "$DATABASE_DIR"
+            chgrp benno "$DATABASE_FILE"
+            chmod 0770 "$DATABASE_DIR"
+            chmod 0660 "$DATABASE_FILE"
+        else
+            echo "WARN --------------------------------------"
+            echo "WARN DB file $DATABASE_FILE not found!"
+            echo "WARN YOU MUST EXTEND THE DATABASE MANUALLY!"
+            echo "WARN --------------------------------------"
+        fi
+
+        if [ ! -f $PUBKEY ] && [ ! -f $SECKEY ];then
+            /usr/lib/benno-imap/benno-rsakeys -p $PUBKEY -s $SECKEY
+            chown benno:benno $SECKEY 2>/dev/null
+            chmod 0440 $SECKEY
+        fi
+        chmod 0750  $CONF_DIR 2>/dev/null
+        chown benno:www-data $CONF_DIR 2>/dev/null
     ;;
     abort-upgrade|abort-remove|abort-deconfigure)
     ;;
